"use strict";
// ------------------------------------------------------------------------------
//  Copyright (c) 2017-present, RobotlegsJS. All Rights Reserved.
//
//  NOTICE: You are permitted to use, modify, and distribute this file
//  in accordance with the terms of the license agreement accompanying it.
// ------------------------------------------------------------------------------
Object.defineProperty(exports, "__esModule", { value: true });
exports.SubCommandMappingList = void 0;
var SubCommandMappingList = /** @class */ (function () {
    function SubCommandMappingList() {
        this._mappings = [];
        this._mappingsByCommand = new Map();
    }
    SubCommandMappingList.prototype.getList = function () {
        return this._mappings.concat();
    };
    SubCommandMappingList.prototype.addMapping = function (mapping) {
        this._storeMapping(mapping);
    };
    SubCommandMappingList.prototype.removeMapping = function (mapping) {
        this._deleteMapping(mapping);
    };
    SubCommandMappingList.prototype.removeMappingsFor = function (commandClass) {
        if (this._mappingsByCommand.has(commandClass)) {
            var subCommandList = this._mappingsByCommand
                .get(commandClass)
                .concat();
            while (subCommandList.length > 0) {
                this._deleteMapping(subCommandList.pop());
            }
        }
    };
    SubCommandMappingList.prototype.removeAllMappings = function () {
        if (this._mappings.length > 0) {
            var subCommandList = this._mappings.concat();
            while (subCommandList.length > 0) {
                this._deleteMapping(subCommandList.pop());
            }
        }
    };
    SubCommandMappingList.prototype._storeMapping = function (mapping) {
        var subCommandList;
        if (!this._mappingsByCommand.has(mapping.commandClass)) {
            subCommandList = [];
            this._mappingsByCommand.set(mapping.commandClass, subCommandList);
        }
        else {
            subCommandList = this._mappingsByCommand.get(mapping.commandClass);
        }
        subCommandList.push(mapping);
        this._mappings.push(mapping);
    };
    SubCommandMappingList.prototype._deleteMapping = function (mapping) {
        var _this = this;
        if (this._mappingsByCommand.has(mapping.commandClass)) {
            var subCommandList_1 = this._mappingsByCommand.get(mapping.commandClass);
            // Ensure that duplicates are removed
            subCommandList_1.concat().forEach(function (m) {
                if (m === mapping) {
                    subCommandList_1.splice(subCommandList_1.indexOf(m), 1);
                }
            });
            if (subCommandList_1.length === 0) {
                this._mappingsByCommand.delete(mapping.commandClass);
            }
        }
        // Ensure that duplicates are removed
        this._mappings.concat().forEach(function (m) {
            if (m === mapping) {
                _this._mappings.splice(_this._mappings.indexOf(m), 1);
            }
        });
    };
    return SubCommandMappingList;
}());
exports.SubCommandMappingList = SubCommandMappingList;
//# sourceMappingURL=SubCommandMappingList.js.map